@@ -32,7 +32,7 @@ nat_lapply <- function(l, ht, v, levels) {
   comp <- v[which(grepl(l_age_comp, names(v)))]
   if (sum(comp) > 0) comp <- (comp / sum(comp)) 
   
-  st <- data.frame(pct= comp, levels= levels)
+  st <- data.frame(pct= comp, levels= factor(levels, levels= levels))
   st <- base::split(st, 1:nrow(st))
   
   dat <- replicate(length(levels), l, simplify = FALSE)
