@@ -24,12 +24,6 @@ test_that("accurately named vector", {
 
 
 test_that("creates expected result", {
-  ##---------------------------------------------------------------------------
-  ## 01. build out test datasets
-  ##---------------------------------------------------------------------------
-  # load
-  load("C:/Github/synthACS/tests/testthat/acsdat.Rdata")
-  
   # then create multiple examples
   ca_ag1 <- synthACS:::synth_data_ag(unlist(ca_dat$estimates$age_by_sex[1,]))
   ca_ag2 <- synthACS:::synth_data_ag(unlist(ca_dat$estimates$age_by_sex[20,]))
